const { Clutter, GObject, St } = imports.gi;
const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;
class Extension {
    constructor(uuid) {
        this._uuid = uuid;
        this._counter = 0;
        this._startOfDay = null;
        this._timerId = 0;
        this._initialize();
    }
    _initialize() {
        this._startOfDay = new Date();
        this._startOfDay.setHours(0, 0, 0, 0);
        this._updateTimer();
    }
    enable() {
        this._indicator = new Indicator(this);
        Main.panel.addToStatusArea(this._uuid, this._indicator, 4, 'left');
    }
    disable() {
        this._indicator.destroy();
        this._indicator = null;
        if (this._timerId) {
            clearTimeout(this._timerId);
            this._timerId = 0;
        }
    }
    incrementCounter() {
        this._counter++;
        this._indicator.updateLabel();
    }
    resetCounter() {
        this._counter = 0;
        this._indicator.updateLabel();
    }
    getCounter() {
        return this._counter;
    }
    _updateTimer() {
        if (this._timerId) {
            clearTimeout(this._timerId);
            this._timerId = 0;
        }
        const currentTime = new Date();
        const timeToMidnight = this._startOfDay.getTime() + 24 * 60 * 60 * 1000 - currentTime.getTime();
        this._timerId = setTimeout(() => {
            this.resetCounter();
            this._updateTimer();
        }, timeToMidnight);
    }
}
const Indicator = GObject.registerClass(
class Indicator extends PanelMenu.Button {
    _init (extension) {
        super._init(0.0, 'Toggle Button');
        this._extension = extension;
        this._label = new St.Label({
            text: ` Urge Count: ${extension.getCounter()} | `,
            y_align: Clutter.ActorAlign.CENTER,
        });
        this.add_child(this._label);
        this.connect('event', this._onClicked.bind(this));
    }
    _onClicked(actor, event) {
        if ((event.type() !== Clutter.EventType.TOUCH_BEGIN && event.type() !== Clutter.EventType.BUTTON_PRESS)) {
            return Clutter.EVENT_PROPAGATE;
        }
        this._extension.incrementCounter();
        return Clutter.EVENT_PROPAGATE;
    }
    updateLabel() {
        this._label.set_text(` Urge Count: ${this._extension.getCounter()} | `);
    }
});
function init(meta) {
    return new Extension(meta.uuid);
}


